@@ -15,7 +15,7 @@ use URI;
 use URI::Escape 'uri_escape_utf8';
 use WWW::OAuth::Util 'oauth_request';
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 my %signature_methods = (
 	'PLAINTEXT' => '_signature_plaintext',
@@ -25,15 +25,25 @@ my %signature_methods = (
 
 sub authenticate {
 	my $self = shift;
-	my @req_args = (shift);
-	push @req_args, shift unless ref $req_args[0];
+	my @req_args = ref $_[0] ? shift() : (shift, shift);
+	my $req = oauth_request(@req_args);
+	
+	my $auth_header = $self->authorization_header($req, @_);
+	
+	$req->header(Authorization => $auth_header);
+	return $req;
+}
+
+sub authorization_header {
+	my $self = shift;
+	my @req_args = ref $_[0] ? shift() : (shift, shift);
 	my $req = oauth_request(@req_args);
 	my $extra_params = shift;
 	
 	my ($client_id, $client_secret, $token, $token_secret, $signature_method) =
 		($self->client_id, $self->client_secret, $self->token, $self->token_secret, $self->signature_method);
 	
-	croak 'Client ID and secret are required to authenticate'
+	croak 'Client ID and secret are required to generate authorization header'
 		unless defined $client_id and defined $client_secret;
 	
 	croak 'RSA-SHA1 signature method requires a coderef or an object with a "sign" method'
@@ -52,20 +62,6 @@ sub authenticate {
 	);
 	$oauth_params{oauth_token} = $token if defined $token;
 	
-	# All oauth parameters should be moved to the header
-	my %query_oauth_params = pairgrep { $a =~ m/^oauth_/ } @{$req->query_pairs};
-	if (%query_oauth_params) {
-		%oauth_params = (%oauth_params, %query_oauth_params);
-		$req->remove_query_params(keys %query_oauth_params);
-	}
-	if ($req->content_is_form) {
-		my %body_oauth_params = pairgrep { $a =~ m/^oauth_/ } @{$req->body_pairs};
-		if (%body_oauth_params) {
-			%oauth_params = (%oauth_params, %body_oauth_params);
-			$req->remove_body_params(keys %body_oauth_params);
-		}
-	}
-	
 	# Extra parameters passed to authenticate()
 	if (defined $extra_params) {
 		croak 'OAuth parameters must be specified as a hashref' unless ref $extra_params eq 'HASH';
@@ -79,8 +75,7 @@ sub authenticate {
 	$oauth_params{oauth_signature} = $self->$sign($req, \%oauth_params, $client_secret, $token_secret);
 	
 	my $auth_str = join ', ', map { $_ . '="' . uri_escape_utf8($oauth_params{$_}) . '"' } sort keys %oauth_params;
-	$req->header(Authorization => "OAuth $auth_str");
-	return $req;
+	return "OAuth $auth_str";
 }
 
 sub _nonce {
@@ -143,6 +138,10 @@ WWW::OAuth - Portable OAuth 1.0 authentication
    token_secret => $token_secret,
  );
  
+ # Just retrieve authorization header
+ my $auth_header = $oauth->authorization_header($http_request, { oauth_callback => $url });
+ $http_request->header(Authorization => $auth_header);
+ 
  # HTTP::Tiny
  use HTTP::Tiny;
  my $res = $oauth->authenticate(Basic => { method => 'GET', url => $url })
@@ -276,10 +275,22 @@ L<WWW::OAuth> implements the following methods.
  my $container = $oauth->authenticate(Basic => { method => 'GET', url => $url }, \%oauth_params);
 
 Wraps the HTTP request in a container with L<WWW::OAuth::Util/"oauth_request">,
-then updates the request URL, content, and headers as needed to construct and
-sign the request for OAuth 1.0. OAuth parameters (starting with C<oauth_>) may
-be optionally specified in a hashref, and will override any generated or
-existing OAuth parameters of the same name. Returns the container object.
+then sets the Authorization header using L</"authorization_header"> to sign the
+request for OAuth 1.0. An optional hashref of OAuth parameters will be passed
+through to L</"authorization_header">. Returns the container object.
+
+=head2 authorization_header
+
+ my $auth_header = $oauth->authorization_header($container, \%oauth_params);
+ my $auth_header = $oauth->authorization_header($http_request, \%oauth_params);
+ my $auth_header = $oauth->authorization_header(Basic => { method => 'GET', url => $url }, \%oauth_params);
+
+Forms an OAuth 1.0 signed Authorization header for the passed request. As in
+L</"authenticate">, the request may be specified in any form accepted by
+L<WWW::OAuth::Util/"oauth_request">. OAuth parameters (starting with C<oauth_>)
+may be optionally specified in a hashref and will override any generated OAuth
+parameters of the same name (they should not be present in the request URL or
+body parameters). Returns the signed header value.
 
 =head1 HTTP REQUEST CONTAINERS
 
